@@ -1,4 +1,4 @@
-import timeit
+import time
 from io import StringIO
 from pathlib import Path
 
@@ -30,6 +30,11 @@ class Command(BaseCommand):
         stdout = StringIO()
         stderr = StringIO()
 
+        # Force DEBUG to always be `False` so that
+        # whitenoise.storage.CompressedManifestStaticFilesStorage will use the static
+        # assets with hashed failenames
+        settings.DEBUG = False
+
         # TODO: Option to remove static files before re-generating
         management.call_command(
             "collectstatic",
@@ -64,8 +69,8 @@ class Command(BaseCommand):
     def output_markdown_file(
         self,
         manifest: Manifest,
+        is_force: bool,
         markdown_file: Path,
-        is_force: bool = False,
     ):
         item = ManifestItem.create(markdown_file)
         existing_item = manifest.get(markdown_file)
@@ -100,12 +105,7 @@ class Command(BaseCommand):
         self.stdout.write(f"{action} {item.generated_file_name}")
 
     def handle(self, *args, **options):
-        start_time = timeit.timeit()
-
-        # Force DEBUG to always be `False` so that
-        # whitenoise.storage.CompressedManifestStaticFilesStorage will use the static
-        # assets with hashed failenames
-        settings.DEBUG = False
+        start_time = time.time()
 
         self.stdout.write(self.style.WARNING("Start generating the static site...\n"))
 
@@ -134,7 +134,7 @@ class Command(BaseCommand):
             self.stdout.write("- Force update because static file(s) updated")
 
         for markdown_file in content_paths:
-            self.output_markdown_file(manifest, markdown_file, is_force)
+            self.output_markdown_file(manifest, is_force, markdown_file)
 
         if manifest.is_dirty:
             self.stdout.write("- Update manifest")
@@ -142,7 +142,7 @@ class Command(BaseCommand):
 
         self.stdout.write()
 
-        elapsed_time = abs((timeit.timeit() - start_time) * 1000)
+        elapsed_time = abs((time.time() - start_time))
         self.stdout.write(
-            self.style.SUCCESS(f"Static site output completed in {elapsed_time:.4f}ms")
+            self.style.SUCCESS(f"Static site output completed in {elapsed_time:.4f}s")
         )
